slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSGetPurify

Returns the flag indicating whether purification is activated or not.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSGetPurify(EPS eps,PetscBool *purify)

Not Collective

### Input Parameter

| eps | - the eigensolver context

### Output Parameter

| purify | - the returned flag

### See Also

EPSSetPurify()

### Level

intermediate

### Location

src/eps/interface/epsopts.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages